==> apache-shardingsphere-5.5.1-src.zip: apache-shardingsphere-5.5.1-src-release/infra/algorithm/type/message-digest/type/md5/src/main/java/org/apache/shardingsphere/infra/algorithm/messagedigest/md5/MD5MessageDigestAlgorithm.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.algorithm.messagedigest.md5;

import org.apache.commons.codec.digest.DigestUtils;
import org.apache.shardingsphere.infra.algorithm.messagedigest.core.MessageDigestAlgorithm;

import java.util.Properties;

/**
 * MD5 message digest algorithm.
 */
public final class MD5MessageDigestAlgorithm implements MessageDigestAlgorithm {
    
    private static final String SALT_KEY = "salt";
    
    private String salt;
    
    @Override
    public void init(final Properties props) {
        salt = props.getProperty(SALT_KEY, "");
    }
    
    @Override
    public String digest(final Object plainValue) {
        return null == plainValue ? null : DigestUtils.md5Hex(plainValue + salt);
    }
    
    @Override
    public String getType() {
        return "MD5";
    }
}

==> apache-shardingsphere-5.5.3-src.zip: apache-shardingsphere-5.5.3-src-release/infra/algorithm/type/message-digest/type/md5/src/main/java/org/apache/shardingsphere/infra/algorithm/messagedigest/md5/MD5MessageDigestAlgorithm.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.infra.algorithm.messagedigest.md5;

import org.apache.commons.codec.digest.DigestUtils;
import org.apache.shardingsphere.infra.algorithm.messagedigest.spi.MessageDigestAlgorithm;
import org.apache.shardingsphere.infra.annotation.HighFrequencyInvocation;

import java.util.Properties;

/**
 * MD5 message digest algorithm.
 */
public final class MD5MessageDigestAlgorithm implements MessageDigestAlgorithm {
    
    private static final String SALT_KEY = "salt";
    
    private String salt;
    
    @Override
    public void init(final Properties props) {
        salt = props.getProperty(SALT_KEY, "");
    }
    
    @HighFrequencyInvocation
    @Override
    public String digest(final Object plainValue) {
        return null == plainValue ? null : DigestUtils.md5Hex(plainValue + salt);
    }
    
    @Override
    public String getType() {
        return "MD5";
    }
}
